@@ -1,7 +1,7 @@
 """System upgrade."""
 
 from argparse import Namespace
-from subprocess import CompletedProcess
+from subprocess import TimeoutExpired, CompletedProcess
 
 from homeinfotools.exceptions import SSHConnectionError
 from homeinfotools.functions import completed_process_to_json, execute
@@ -17,11 +17,9 @@ from homeinfotools.ssh import ssh
 __all__ = ['sysupgrade']
 
 
-PACMAN_WRAPPER = '%s; EXIT_CODE=$?; wait; exit ${EXIT_CODE};'
-
-
-def lograise(system: int, message: str,
-             completed_process: CompletedProcess) -> None:
+def lograise(
+        system: int, message: str, completed_process: CompletedProcess
+) -> None:
     """Issues a warning message and raises an exception."""
 
     if completed_process.returncode == 255:
@@ -49,7 +47,7 @@ def upgrade_keyring(system: int, args: Namespace) -> CompletedProcess:
     command = sudo(*command)
     command = ssh(system, *command, no_stdin=args.no_stdin)
     syslogger(system).debug('Executing command: %s', command)
-    return execute(command)
+    return execute(command, timeout=args.timeout)
 
 
 def upgrade_system(system: int, args: Namespace) -> CompletedProcess:
@@ -72,9 +70,9 @@ def upgrade_system(system: int, args: Namespace) -> CompletedProcess:
     if args.yes:
         command = f'yes | {command}'
 
-    command = ssh(system, PACMAN_WRAPPER % command, no_stdin=args.no_stdin)
+    command = ssh(system, command, no_stdin=args.no_stdin)
     syslogger(system).debug('Executing command: %s', command)
-    return execute(command)
+    return execute(command, timeout=args.timeout)
 
 
 def cleanup_system(system: int, args: Namespace) -> CompletedProcess:
@@ -90,9 +88,9 @@ def cleanup_system(system: int, args: Namespace) -> CompletedProcess:
     if args.yes:
         command = f'yes | {command}'
 
-    command = ssh(system, PACMAN_WRAPPER % command, no_stdin=args.no_stdin)
+    command = ssh(system, command, no_stdin=args.no_stdin)
     syslogger(system).debug('Executing command: %s', command)
-    return execute(command)
+    return execute(command, timeout=args.timeout)
 
 
 def upgrade(system: int, args: Namespace) -> dict:
@@ -124,8 +122,8 @@ def upgrade(system: int, args: Namespace) -> dict:
     return result
 
 
-def sysupgrade(system: int, args: Namespace) -> bool:
-    """Upgrated the respective system."""
+def sysupgrade(system: int, args: Namespace) -> dict:
+    """Upgrades the respective system."""
 
     try:
         return upgrade(system, args)
@@ -133,6 +131,12 @@ def sysupgrade(system: int, args: Namespace) -> bool:
         syslogger(system).error('I/O error.')
         syslogger(system).debug('%s', error)
         return completed_process_to_json(error.completed_process)
+    except TimeoutExpired as error:
+        syslogger(system).error(
+            'Subprocess timed out after %s seconds.', error.timeout
+        )
+        syslogger(system).debug('%s', error)
+        return {'timeout': error.timeout}
     except PacmanError as error:
         syslogger(system).error('Pacman error.')
         syslogger(system).debug('%s', error)
