@@ -2,7 +2,7 @@
 
 from functools import cache
 from pathlib import Path
-from subprocess import CalledProcessError, check_call
+from subprocess import DEVNULL, CalledProcessError, check_call
 
 from homeinfotools.os import SSH, RSYNC
 
@@ -90,7 +90,7 @@ def get_remote_path(path: HostPath) -> str:
     except TypeError:
         return path
 
-    return HOSTNAME.format(system) + f':{path}'
+    return HOSTNAME.format(f'{get_ssh_user(system)}@{system}') + f':{path}'
 
 
 @cache
@@ -99,7 +99,11 @@ def get_ssh_user(system: int) -> str | None:
 
     for user in USERS:
         try:
-            check_call(ssh(system, TRUE, user=user))
+            check_call(
+                ssh(system, TRUE, user=user),
+                stdout=DEVNULL,
+                stderr=DEVNULL
+            )
         except CalledProcessError:
             continue
 
